@@ -1,6 +1,6 @@
 package Koha::Contrib::Sudoc::Loader::Biblios;
 # ABSTRACT: Chargeur de notices biblio
-$Koha::Contrib::Sudoc::Loader::Biblios::VERSION = '2.37';
+$Koha::Contrib::Sudoc::Loader::Biblios::VERSION = '2.38';
 use Moose;
 
 extends 'Koha::Contrib::Sudoc::Loader';
@@ -8,8 +8,8 @@ extends 'Koha::Contrib::Sudoc::Loader';
 use Modern::Perl;
 use utf8;
 use YAML;
-use C4::Biblio;
-use C4::Items;
+use C4::Biblio qw/ ModBiblio ModBiblioMarc AddBiblio /;
+use C4::Items qw/ AddItemBatchFromMarc /;
 
 
 
@@ -161,7 +161,7 @@ Koha::Contrib::Sudoc::Loader::Biblios - Chargeur de notices biblio
 
 =head1 VERSION
 
-version 2.37
+version 2.38
 
 =head1 AUTHOR
 
